package org.apache.bcel.util;

import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.bcel.classfile.JavaClass;

public class LruCacheClassPathRepository extends AbstractClassPathRepository {
   private final LinkedHashMap<String, JavaClass> loadedClasses;

   public LruCacheClassPathRepository(ClassPath path, final int cacheSize) {
      super(path);
      if (cacheSize < 1) {
         throw new IllegalArgumentException("cacheSize must be a positive number.");
      } else {
         int initialCapacity = (int)(0.75 * (double)cacheSize);
         boolean accessOrder = true;
         this.loadedClasses = new LinkedHashMap<String, JavaClass>(initialCapacity, (float)cacheSize, true) {
            private static final long serialVersionUID = 1L;

            protected boolean removeEldestEntry(Map.Entry<String, JavaClass> eldest) {
               return this.size() > cacheSize;
            }
         };
      }
   }

   public void clear() {
      this.loadedClasses.clear();
   }

   public JavaClass findClass(String className) {
      return (JavaClass)this.loadedClasses.get(className);
   }

   public void removeClass(JavaClass javaClass) {
      this.loadedClasses.remove(javaClass.getClassName());
   }

   public void storeClass(JavaClass javaClass) {
      this.loadedClasses.put(javaClass.getClassName(), javaClass);
      javaClass.setRepository(this);
   }
}
